@@ -79,7 +79,7 @@ def login(username: str = None, password: str = None, mfa_code: str = None,
     r = oauth(payload)
     if r.status_code == 400:
         r = r.json()
-        if 'detail' in r and r['detail'] == 'Request blocked, challenge type required.':
+        if r.get('detail') == 'Request blocked, challenge type required.':
             challenge_type = None
             while challenge_type not in ['1', '2']:
                 print('Unfamiliar device detected.')
@@ -113,6 +113,9 @@ def login(username: str = None, password: str = None, mfa_code: str = None,
             session.headers['X-ROBINHOOD-CHALLENGE-RESPONSE-ID'] = challenge_id
             oauth(payload)
             del session.headers['X-ROBINHOOD-CHALLENGE-RESPONSE-ID']
+        elif r.get('detail') == 'Request blocked, prompt challenge issued.':
+            raise RuntimeError('Device approval authentication not supported by this package. '
+                               'Please switch to another authentication method.')
         else:
             raise RuntimeError('Unable to log in with provided credentials.')
 
@@ -123,7 +126,7 @@ def login(username: str = None, password: str = None, mfa_code: str = None,
         if no_input:
             raise RuntimeError('Multi-factor authentication is enabled. "mfa_code" required.')
         else:
-            mfa_code = input('Enter the code generated by your authentication app: ')
+            mfa_code = input('Enter the code from your authenticator app or text message: ')
             return login(username=username, password=password, mfa_code=mfa_code, device_token=device_token,
                          bearer_token=bearer_token, no_input=no_input)
     else:
